@@ -78,8 +78,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -108,8 +108,13 @@ class Confluence(AtlassianRestAPI):
         :type page_id: str
         :return:
         """
-        parent_content_id = ((self.get_page_by_id(page_id=page_id, expand='ancestors').get('ancestors') or {})[-1].get(
-            'id') or None)
+        parent_content_id = None
+        try:
+            parent_content_id = (
+                        (self.get_page_by_id(page_id=page_id, expand='ancestors').get('ancestors') or {})[-1].get(
+                            'id') or None)
+        except Exception as e:
+            log.error(e)
         return parent_content_id
 
     def get_page_space(self, page_id):
@@ -168,8 +173,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 404:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view the content"
-                )(e)
+                    "The calling user does not have permission to view the content",
+                    reason=e)
 
             raise
         try:
@@ -188,8 +193,7 @@ class Confluence(AtlassianRestAPI):
         :param page_id: Content ID
         :param status: (str) list of Content statuses to filter results on. Default value: [current]
         :param version: (int)
-        :param expand: OPTIONAL: A comma separated list of properties to expand on the content.
-                       Default value: history,space,version
+        :param expand: OPTIONAL: Default value: history,space,version
                        We can also specify some extensions such as extensions.inlineProperties
                        (for getting inline comment-specific properties) or extensions.resolution
                        for the resolution status of each comment in the results
@@ -211,8 +215,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -246,8 +250,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -284,8 +288,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -305,8 +309,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 404:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view the content"
-                )(e)
+                    "The calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -335,7 +339,7 @@ class Confluence(AtlassianRestAPI):
             response = self.get(url, params=params)
         except HTTPError as e:
             if e.response.status_code == 400:
-                raise ApiValueError("The CQL is invalid or missing")(e)
+                raise ApiValueError("The CQL is invalid or missing", reason=e)
 
             raise
 
@@ -378,8 +382,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 404:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view the content"
-                )(e)
+                    "The calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -435,8 +439,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 404:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view the content"
-                )(e)
+                    "The calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -485,12 +489,12 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, or the calling "
-                    "user does not have permission to trash or purge the content"
-                )(e)
+                    "user does not have permission to trash or purge the content",
+                    reason=e)
             if e.response.status_code == 409:
                 raise ApiConflictError(
-                    "There is a stale data object conflict when trying to delete a draft"
-                )(e)
+                    "There is a stale data object conflict when trying to delete a draft",
+                    reason=e)
 
             raise
 
@@ -520,12 +524,12 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, or the calling "
-                    "user does not have permission to trash or purge the content"
-                )(e)
+                    "user does not have permission to trash or purge the content",
+                    reason=e)
             if e.response.status_code == 409:
                 raise ApiConflictError(
-                    "There is a stale data object conflict when trying to delete a draft"
-                )(e)
+                    "There is a stale data object conflict when trying to delete a draft",
+                    reason=e)
 
             raise
 
@@ -560,8 +564,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 404:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view the content"
-                )(e)
+                    "The calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -620,8 +624,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 404:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view the content"
-                )(e)
+                    "The calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -674,15 +678,15 @@ class Confluence(AtlassianRestAPI):
                     # Raise ApiError as the documented reason is ambiguous
                     raise ApiError(
                         "Attachments are disabled or the calling user does "
-                        "not have permission to add attachments to this content"
-                    )(e)
+                        "not have permission to add attachments to this content",
+                        reason=e)
                 if e.response.status_code == 404:
                     # Raise ApiError as the documented reason is ambiguous
                     raise ApiError(
                         "The requested content is not found, the user does not have "
                         "permission to view it, or the attachments exceeds the maximum "
-                        "configured attachment size"
-                    )(e)
+                        "configured attachment size",
+                        reason=e)
 
                 raise
 
@@ -811,8 +815,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -836,8 +840,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -860,14 +864,14 @@ class Confluence(AtlassianRestAPI):
             if e.response.status_code == 403:
                 raise ApiPermissionError(
                     "The user has view permission, "
-                    "but no edit permission to the content"
-                )(e)
+                    "but no edit permission to the content",
+                    reason=e)
             if e.response.status_code == 404:
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "The content or label doesn't exist, "
-                    "or the calling user doesn't have view permission to the content"
-                )(e)
+                    "or the calling user doesn't have view permission to the content",
+                    reason=e)
 
             raise
 
@@ -882,8 +886,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -1061,12 +1065,12 @@ class Confluence(AtlassianRestAPI):
                     raise ApiValueError(
                         "No space or no content type, or setup a wrong version "
                         "type set to content, or status param is not draft and "
-                        "status content is current"
-                    )(e)
+                        "status content is current",
+                        reason=e)
                 if e.response.status_code == 404:
                     raise ApiNotFoundError(
-                        "Can not find draft with current content"
-                    )(e)
+                        "Can not find draft with current content",
+                        reason=e)
 
                 raise
 
@@ -1120,12 +1124,12 @@ class Confluence(AtlassianRestAPI):
                     raise ApiValueError(
                         "No space or no content type, or setup a wrong version "
                         "type set to content, or status param is not draft and "
-                        "status content is current"
-                    )(e)
+                        "status content is current",
+                        reason=e)
                 if e.response.status_code == 404:
                     raise ApiNotFoundError(
-                        "Can not find draft with current content"
-                    )(e)
+                        "Can not find draft with current content",
+                        reason=e)
 
                 raise
 
@@ -1187,7 +1191,7 @@ class Confluence(AtlassianRestAPI):
 
         if self.page_exists(space, title):
             page_id = self.get_page_id(space, title)
-            parent_id = self.get_parent_content_id(page_id)
+            parent_id = parent_id if parent_id is not None else self.get_parent_content_id(page_id)
             result = self.update_page(parent_id=parent_id, page_id=page_id, title=title, body=body,
                                       representation=representation, minor_edit=minor_edit,
                                       version_comment=version_comment)
@@ -1237,15 +1241,15 @@ class Confluence(AtlassianRestAPI):
                 raise ApiValueError(
                     "The given property has a different content id to the one in the "
                     "path, or the content already has a value with the given key, or "
-                    "the value is missing, or the value is too long"
-                )(e)
+                    "the value is missing, or the value is too long",
+                    reason=e)
             if e.response.status_code == 403:
                 raise ApiPermissionError(
                     "The user does not have permission to "
-                    "edit the content with the given id"
-                )(e)
+                    "edit the content with the given id",
+                    reason=e)
             if e.response.status_code == 413:
-                raise ApiValueError("The value is too long")(e)
+                raise ApiValueError("The value is too long", reason=e)
 
             raise
 
@@ -1267,8 +1271,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -1292,8 +1296,8 @@ class Confluence(AtlassianRestAPI):
                 raise ApiError(
                     "There is no content with the given id, or no property with the "
                     "given key, or the calling user does not have permission to view "
-                    "the content"
-                )(e)
+                    "the content",
+                    reason=e)
 
             raise
 
@@ -1314,8 +1318,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no content with the given id, "
-                    "or the calling user does not have permission to view the content"
-                )(e)
+                    "or the calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -1334,8 +1338,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 404:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view the content"
-                )(e)
+                    "The calling user does not have permission to view the content",
+                    reason=e)
 
             raise
 
@@ -1372,8 +1376,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 403:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view groups"
-                )(e)
+                    "The calling user does not have permission to view groups",
+                    reason=e)
 
             raise
 
@@ -1400,8 +1404,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 403:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view users"
-                )(e)
+                    "The calling user does not have permission to view users",
+                    reason=e)
 
             raise
 
@@ -1425,8 +1429,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no space with the given key, "
-                    "or the calling user does not have permission to view the space"
-                )(e)
+                    "or the calling user does not have permission to view the space",
+                    reason=e)
             raise
         return response
 
@@ -1466,8 +1470,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no space with the given key, "
-                    "or the calling user does not have permission to delete it"
-                )(e)
+                    "or the calling user does not have permission to delete it",
+                    reason=e)
 
             raise
 
@@ -1486,8 +1490,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no space with the given key, "
-                    "or the calling user does not have permission to view the space"
-                )(e)
+                    "or the calling user does not have permission to view the space",
+                    reason=e)
 
             raise
 
@@ -1511,12 +1515,12 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 403:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view users"
-                )(e)
+                    "The calling user does not have permission to view users",
+                    reason=e)
             if e.response.status_code == 404:
                 raise ApiNotFoundError(
-                    "The user with the given username or userkey does not exist"
-                )(e)
+                    "The user with the given username or userkey does not exist",
+                    reason=e)
 
             raise
 
@@ -1540,12 +1544,12 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 403:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to view users"
-                )(e)
+                    "The calling user does not have permission to view users",
+                    reason=e)
             if e.response.status_code == 404:
                 raise ApiNotFoundError(
-                    "The user with the given username or userkey does not exist"
-                )(e)
+                    "The user with the given username or userkey does not exist",
+                    reason=e)
 
             raise
 
@@ -1585,7 +1589,7 @@ class Confluence(AtlassianRestAPI):
             response = self.get('rest/api/search', params=params)
         except HTTPError as e:
             if e.response.status_code == 400:
-                raise ApiValueError("The query cannot be parsed")(e)
+                raise ApiValueError("The query cannot be parsed", reason=e)
 
             raise
 
@@ -1640,7 +1644,7 @@ class Confluence(AtlassianRestAPI):
             response = self.get(url, {})
         except HTTPError as e:
             if e.response.status_code == 400:
-                raise ApiValueError("The CQL is invalid or missing")(e)
+                raise ApiValueError("The CQL is invalid or missing", reason=e)
 
             raise
 
@@ -1710,8 +1714,8 @@ class Confluence(AtlassianRestAPI):
         except HTTPError as e:
             if e.response.status_code == 403:
                 raise ApiPermissionError(
-                    "The calling user does not have permission to use Confluence"
-                )(e)
+                    "The calling user does not have permission to use Confluence",
+                    reason=e)
 
             raise
 
@@ -1777,8 +1781,8 @@ class Confluence(AtlassianRestAPI):
                 # Raise ApiError as the documented reason is ambiguous
                 raise ApiError(
                     "There is no task with the given key, "
-                    "or the calling user does not have permission to view it"
-                )(e)
+                    "or the calling user does not have permission to view it",
+                    reason=e)
 
             raise
 
